/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <SDL.h>
#include <iostream>
#include <sstream>
#include <GL/gl.h>
#include "video.h"

#define RES_X 640
#define RES_Y 480

using namespace std;

CAMERA camera;

int init_video() {
	if(SDL_Init(SDL_INIT_VIDEO) != 0) {
		std::cerr << "Couldn't initialize SDL: " << SDL_GetError() << endl;
	}

	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
	SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 5);
	SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 6);
	SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 5);

	if(SDL_SetVideoMode(RES_X, RES_Y, 16, SDL_OPENGL) == NULL) {
		std::cerr << "Couldn't create rendering context: " << SDL_GetError() << endl;
		return -1;
	}
	SDL_WM_SetCaption("Proteus RPG Engine", NULL);

	glViewport(0, 0, RES_X, RES_Y);
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glFrustum(-1.0f, 1.0f, -1.0f, 1.0f, 1.0f, 1000.0f);
	glShadeModel(GL_SMOOTH);
	glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
	glClearDepth(1.0f);
	glEnable(GL_DEPTH_TEST);
	glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
   
	glMatrixMode(GL_MODELVIEW);
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	glLoadIdentity();
 
	camera.x = 0.0f;
	camera.y = 0.0f;
	camera.z = 1000.0f;
	camera.pitch = 0.0f;
	camera.roll = 0.0f;
	camera.yaw = 0.0f;

	printf("VID: Initialized\n");
	return 0;
}

void video_take_screenshot() {
	cout << "Taking screenshot!\n";
	SDL_Surface *surface;
	surface = SDL_CreateRGBSurface(SDL_SWSURFACE, RES_X, RES_Y, 32, 0xff000000, 0x00ff0000, 0x0000ff00, 0x000000ff);
	glReadPixels(0, 0, RES_X, RES_Y, GL_RGBA, GL_UNSIGNED_INT_8_8_8_8, surface->pixels);

	SDL_SaveBMP(surface, "ss.bmp");
}

